@@ -448,7 +448,7 @@ int setRootDir(const char *dpath)
 		sprintf(logPath, "%s/%s", logger->rootPath, logger->logfileName.commonlogfileName);
 		char canonical_filename[PATH_MAX] = "\0";
 		memset(canonical_filename,0,PATH_MAX);
-		int ret = realpath(logPath, canonical_filename);
+		realpath(logPath, canonical_filename);
 		if(!verify_file(canonical_filename))
 		{
 			return -1;
